==> v1.0.2.tar.gz: dchat/web/src/main/java/de/hhhammer/dchat/web/WebAPI.java <==
package de.hhhammer.dchat.web;

import de.hhhammer.dchat.db.ServerDBService;
import de.hhhammer.dchat.db.UserDBService;
import de.hhhammer.dchat.web.server.ConfigCrudHandler;
import de.hhhammer.dchat.web.user.ConfigUserCrudHandler;
import io.javalin.Javalin;
import io.javalin.http.HttpStatus;
import io.javalin.http.staticfiles.Location;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.concurrent.CompletableFuture;
import java.util.concurrent.ExecutionException;

import static io.javalin.apibuilder.ApiBuilder.crud;
import static io.javalin.apibuilder.ApiBuilder.path;

public class WebAPI implements Runnable {
    private static final Logger logger = LoggerFactory.getLogger(WebAPI.class);
    private final ServerDBService serverDBService;
    private final UserDBService userDBService;
    private final AppConfig appConfig;

    public WebAPI(ServerDBService serverDBService, UserDBService userDBService, AppConfig appConfig) {
        this.serverDBService = serverDBService;
        this.userDBService = userDBService;
        this.appConfig = appConfig;
    }

    @Override
    public void run() {
        logger.info("Starting web application");
        var app = Javalin.create(config -> {
            if (appConfig.debug()) config.plugins.enableDevLogging();
            config.http.prefer405over404 = true;  // return 405 instead of 404 if path is mapped to different HTTP method
            config.http.defaultContentType = "application/json";
        });
        var waitForShutdown = new CompletableFuture<Void>();
        Runtime.getRuntime().addShutdownHook(new Thread(() -> {
            logger.info("Shutting down web application");
            app.stop();
            waitForShutdown.complete(null);

        }));
        app.events(event -> {
            event.serverStopping(() -> logger.info("Stopping web service"));
            event.serverStopped(() -> logger.info("Stopped web service"));
        });
        app.before(ctx -> {
            ctx.header("Access-Control-Allow-Origin", "*");
            ctx.header("Access-Control-Allow-Methods", "*");
        });
        app.options("*", ctx -> ctx.status(HttpStatus.OK));

        app.routes(() -> {
            path("api", () -> {
                path("servers", () -> {
                    crud("configs/{id}", new ConfigCrudHandler(this.serverDBService));
                });
                path("users", () -> {
                    crud("configs/{id}", new ConfigUserCrudHandler(this.userDBService));
                });
            });
        });

        app.start(appConfig.port());
        try {
            waitForShutdown.get();
        } catch (InterruptedException | ExecutionException e) {
            throw new RuntimeException(e);
        }
    }
}

==> v1.0.3.tar.gz: dchat/web/src/main/java/de/hhhammer/dchat/web/WebAPI.java <==
package de.hhhammer.dchat.web;

import de.hhhammer.dchat.db.ServerDBService;
import de.hhhammer.dchat.db.UserDBService;
import de.hhhammer.dchat.web.server.ConfigCrudHandler;
import de.hhhammer.dchat.web.user.ConfigUserCrudHandler;
import io.javalin.Javalin;
import io.javalin.http.HttpStatus;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.concurrent.CompletableFuture;
import java.util.concurrent.ExecutionException;

import static io.javalin.apibuilder.ApiBuilder.crud;
import static io.javalin.apibuilder.ApiBuilder.path;

public final class WebAPI implements Runnable {
    private static final Logger logger = LoggerFactory.getLogger(WebAPI.class);
    private final ServerDBService serverDBService;
    private final UserDBService userDBService;
    private final AppConfig appConfig;

    public WebAPI(final ServerDBService serverDBService, final UserDBService userDBService, final AppConfig appConfig) {
        this.serverDBService = serverDBService;
        this.userDBService = userDBService;
        this.appConfig = appConfig;
    }

    @Override
    public void run() {
        logger.info("Starting web application");
        final Javalin app = Javalin.create(config -> {
            if (appConfig.debug()) config.plugins.enableDevLogging();
            config.http.prefer405over404 = true;  // return 405 instead of 404 if path is mapped to different HTTP method
            config.http.defaultContentType = "application/json";
        });
        final var waitForShutdown = new CompletableFuture<Void>();
        Runtime.getRuntime().addShutdownHook(new Thread(() -> {
            logger.info("Shutting down web application");
            app.stop();
            waitForShutdown.complete(null);

        }));
        app.events(event -> {
            event.serverStopping(() -> logger.info("Stopping web service"));
            event.serverStopped(() -> logger.info("Stopped web service"));
        });
        app.before(ctx -> {
            ctx.header("Access-Control-Allow-Origin", "*");
            ctx.header("Access-Control-Allow-Methods", "*");
        });
        app.options("*", ctx -> ctx.status(HttpStatus.OK));

        app.routes(() -> {
            path("api", () -> {
                path("servers", () -> {
                    crud("configs/{id}", new ConfigCrudHandler(this.serverDBService));
                });
                path("users", () -> {
                    crud("configs/{id}", new ConfigUserCrudHandler(this.userDBService));
                });
            });
        });

        app.start(appConfig.port());
        try {
            waitForShutdown.get();
        } catch (InterruptedException | ExecutionException e) {
            throw new RuntimeException(e);
        }
    }
}
